@@ -1,5 +1,5 @@
 package MooX::Role::POE::Emitter;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Moo::Role;
 
@@ -95,6 +95,14 @@ has 'session_id' => (
   default   => sub { -1 },
 );
 
+has 'shutdown_signal' => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Str,
+  predicate => 'has_shutdown_signal',
+  writer    => 'set_shutdown_signal',
+  default   => sub { 'SHUTDOWN_EMITTER' },
+);
 
 has '__emitter_reg_sessions' => (
   ## ->{ $session_id } = { refc => $ref_count, id => $id };
@@ -164,6 +172,8 @@ sub _start_emitter {
         __emitter_sigdie
 
         __emitter_reset_alias
+
+        __emitter_sig_shutdown
       / ],
 
       (
@@ -227,17 +237,18 @@ sub timer_del {
 sub __emitter_timer_del {
   my ($kernel, $self, $alarm_id) = @_[KERNEL, OBJECT, ARG0];
 
-  if ( my @deleted = $poe_kernel->alarm_remove($alarm_id) ) {
-    my ($event, undef, $params) = @deleted;
-    $self->emit( $self->event_prefix . 'timer_deleted',
+  my @deleted = $poe_kernel->alarm_remove($alarm_id);
+  return unless @deleted;
+
+  my ($event, undef, $params) = @deleted;
+
+  $self->emit( $self->event_prefix . 'timer_deleted',
       $alarm_id,
       $event,
       @{$params||[]}
-    );
-    return $params
-  }
+  );
 
-  return
+  return $params
 }
 
 ## yield/call provide post()/call() frontends.
@@ -296,6 +307,7 @@ sub _trigger_object_states {
     _start
     _stop
     _default
+    emit
     register
     unregister
     subscribe
@@ -408,15 +420,14 @@ sub __emitter_start {
 
   $self->set_session_id( $session->ID );
 
-  $kernel->sig('DIE', '__emitter_sigdie' );
-
   $kernel->alias_set( $self->alias );
 
-  my $s_id = $sender->ID;
+  $kernel->sig('DIE', '__emitter_sigdie' );
+  $kernel->sig( $self->shutdown_signal, '__emitter_sig_shutdown' );
 
   unless ($sender == $kernel) {
     ## Have a parent session.
-
+    my $s_id = $sender->ID;
     $kernel->refcount_increment( $s_id, E_TAG );
     $self->__incr_ses_refc( $s_id );
     $self->__reg_ses_id( $s_id );
@@ -470,6 +481,11 @@ sub _emitter_default {
     or $event =~ /^emitter_(?:started|stopped)$/ ;
 }
 
+sub __emitter_sig_shutdown {
+  my ($kernel, $self) = @_[KERNEL, OBJECT];
+  $self->yield('shutdown_emitter', @_[ARG2 .. $#_] )
+}
+
 sub __emitter_sigdie {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   my $exh = $_[ARG1];
@@ -619,7 +635,7 @@ MooX::Role::POE::Emitter - Pluggable POE event emitter role for cows
         ## Maybe include from named arguments, for example:
         (
           ref $args{object_states} eq 'ARRAY' ?
-            @{ $args{object_states } : ()
+            @{ $args{object_states} } : ()
         ),
       ],
     );
@@ -768,6 +784,11 @@ Set via B<set_register_prefix>
 B<session_id> is our emitter's L<POE::Session> ID, set when our Session is 
 started via L</"_start_emitter">.
 
+=head4 shutdown_signal
+
+B<shutdown_signal> is the name of the L<POE> signal that will trigger a 
+shutdown (used to shut down multiple Emitters). See L</"Signals">
+
 =head3 _start_emitter
 
 B<_start_emitter()> should be called on our object to spawn the actual
@@ -996,6 +1017,18 @@ A prefixed (L</event_prefix>) 'timer_deleted' event is emitted when a timer
 is deleted. Arguments are the removed alarm ID, the event name or coderef, 
 and any event parameters, respectively.
 
+=head2 Signals
+
+=head3 Shutdown Signal
+
+The attribute L</shutdown_signal> defines a POE signal that will trigger a 
+shutdown; it defaults to C<SHUTDOWN_EMITTER>:
+
+  ## Shutdown *all* emitters (with a default shutdown_signal()):
+  $poe_kernel->signal( $poe_kernel, 'SHUTDOWN_EMITTER' );
+
+See L<POE::Kernel/"Signal Watcher Methods"> for details on L<POE> signals.
+
 =head2 Moose compatibility
 
 This Role "seems to be" Moose-compatible as of version 0.07, but you'll 
